@@ -70,6 +70,10 @@ class KNXTime(NamedTuple):
     time: datetime.time
     weekday: Optional[int]
 
+    @classmethod
+    def from_datetime(cls, value: datetime.datetime):
+        return cls(value.time, value.weekday())
+
 
 def encode_value(value: Any, t: KNXDPT) -> EncodedData:
     """
